==> web-9.0.0.tgz: package/lib/treeTable/TabView.js <==
import * as React from "react";
import ParTree from './ParTree';
import TrItem from './TrItem';
class TabView extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.colHeadRef = React.createRef();
        this.tabBodyRef = React.createRef();
        this.state = {};
        this.scrollFn = (e) => {
            if (!e.currentTarget.classList.contains('action-body')) {
                return;
            }
            const { changeScrollTop, viewIndex } = this.props;
            const dom = e.currentTarget;
            const left = dom.scrollLeft;
            const colHead = this.colHeadRef.current;
            colHead.scrollLeft = left;
            changeScrollTop(dom.scrollTop, viewIndex);
        };
        this.wheelFn = (e) => {
            e.preventDefault();
            const { changeScrollTop, viewIndex } = this.props;
            const deltay = e.deltaY;
            const top = this.tabBodyRef.current.scrollTop;
            const distance = top + deltay;
            this.tabBodyRef.current.scrollTop = distance;
            changeScrollTop(distance, viewIndex);
        };
        this.makeSign = (e) => {
            e.preventDefault();
            const type = e.type;
            const dom = e.currentTarget;
            if (type === "mouseenter") {
                dom.classList.add('action-body');
            }
            else if (type === "mouseleave") {
                dom.classList.remove('action-body');
            }
        };
    }
    gethead() {
        const { config: { child: cols } } = this.props;
        const tds = cols.map(val => {
            const { text, width, field } = val;
            return (React.createElement("th", { style: { width: width, }, className: "td-border", key: field }, text));
        });
        return (React.createElement("div", { className: "tab-head" },
            React.createElement("table", null,
                React.createElement("thead", null,
                    React.createElement("tr", null, tds)))));
    }
    createColgroup() {
        const { config: { child: cols } } = this.props;
        const arr = cols.map(val => {
            const { width, field } = val;
            const style = width ? { width } : undefined;
            return (React.createElement("col", { style: style, key: field }));
        });
        return (React.createElement("colgroup", null, arr));
    }
    componentDidMount() {
        const { setTabBodyDom, viewIndex, config } = this.props;
        if (!config.forzen) {
            this.overBox();
        }
        const { current } = this.tabBodyRef;
        setTabBodyDom(current, viewIndex);
        if (config.forzen) {
            current.addEventListener("wheel", this.wheelFn);
        }
    }
    componentWillUnmount() {
        const { config } = this.props;
        if (config.forzen) {
            this.tabBodyRef.current.removeEventListener("wheel", this.wheelFn);
        }
    }
    overBox() {
        const tbodyDom = this.tabBodyRef.current;
        if (tbodyDom.scrollWidth > tbodyDom.clientWidth) {
            const child = this.colHeadRef.current.firstElementChild;
            child.style.paddingRight = "18px";
        }
    }
    getBody() {
        const { data, fixObj, fixObj: { idField, childField }, config, viewIndex, changeState } = this.props;
        const { child: cols } = config;
        let order = { order: 0 };
        const trs = data.map((val, index) => {
            const arr = val.get(childField);
            const id = val.get(idField);
            const isMainView = viewIndex === 0;
            if (arr && arr.size) {
                return (React.createElement(ParTree, { key: id, order: order, changeState: changeState, lev: 0, index: `${index}`, node: val, cols: cols, isMainView: isMainView, fixObj: fixObj }));
            }
            else {
                return (React.createElement(TrItem, { key: id, order: order, node: val, index: `${index}`, changeState: changeState, cols: cols, isMainView: isMainView, lev: 0, fixObj: fixObj }));
            }
        });
        const colgroup = this.createColgroup();
        const fn = !config.forzen ? this.scrollFn : undefined;
        const makeSignFn = !config.forzen ? this.makeSign : undefined;
        return (React.createElement("div", { className: "tab-body-main", onScroll: fn, onMouseEnter: makeSignFn, onMouseLeave: makeSignFn, ref: this.tabBodyRef },
            React.createElement("table", null,
                colgroup,
                React.createElement("tbody", null, trs))));
    }
    render() {
        const { config: { width, forzen }, config } = this.props;
        const styleObj = width && forzen ? { width } : undefined;
        const className = config.forzen ? "tab-view-fix" : "tab-view-scroll";
        return (React.createElement("div", { className: `${className} tab-viewBody`, style: styleObj },
            React.createElement("div", { className: "tab-head-wrap", ref: this.colHeadRef }, this.gethead()),
            React.createElement("div", { className: "tab-body-wrap" }, this.getBody())));
    }
}
export default TabView;

==> web-10.0.0.tgz: package/lib/treeTable/TabView.js <==
import * as React from "react";
import ParTree from "./ParTree";
import TrItem from "./TrItem";
class TabView extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.colHeadRef = React.createRef();
        this.tabBodyRef = React.createRef();
        this.state = {};
        this.overBoxTimer = 0;
        this.scrollFn = (e) => {
            if (!e.currentTarget.classList.contains("action-body")) {
                return;
            }
            const { changeScrollTop, viewIndex } = this.props;
            const dom = e.currentTarget;
            const left = dom.scrollLeft;
            const colHead = this.colHeadRef.current;
            colHead.scrollLeft = left;
            changeScrollTop(dom.scrollTop, viewIndex);
        };
        this.wheelFn = (e) => {
            e.preventDefault();
            const { changeScrollTop, viewIndex } = this.props;
            const deltay = e.deltaY;
            const top = this.tabBodyRef.current.scrollTop;
            const distance = top + deltay;
            this.tabBodyRef.current.scrollTop = distance;
            changeScrollTop(distance, viewIndex);
        };
        this.makeSign = (e) => {
            e.preventDefault();
            const type = e.type;
            const dom = e.currentTarget;
            if (type === "mouseenter") {
                dom.classList.add("action-body");
            }
            else if (type === "mouseleave") {
                dom.classList.remove("action-body");
            }
        };
    }
    gethead() {
        const { config: { child: cols }, } = this.props;
        const tds = cols.map((val) => {
            const { text, width, field } = val;
            return (React.createElement("th", { style: { width: width }, className: "td-border", key: field }, text));
        });
        return (React.createElement("div", { className: "tab-head" },
            React.createElement("table", null,
                React.createElement("thead", null,
                    React.createElement("tr", null, tds)))));
    }
    createColgroup() {
        const { config: { child: cols }, } = this.props;
        const arr = cols.map((val) => {
            const { width, field } = val;
            const style = width ? { width } : undefined;
            return React.createElement("col", { style: style, key: field });
        });
        return React.createElement("colgroup", null, arr);
    }
    componentDidMount() {
        const { setTabBodyDom, viewIndex, config } = this.props;
        if (!config.forzen) {
            this.overBox();
        }
        const { current } = this.tabBodyRef;
        setTabBodyDom(current, viewIndex);
        if (config.forzen) {
            current.addEventListener("wheel", this.wheelFn);
        }
    }
    componentDidUpdate(preProps) {
        if (preProps.data !== this.props.data) {
            clearTimeout(this.overBoxTimer);
            const tbodyDom = this.tabBodyRef.current;
            const child = this.colHeadRef.current
                .firstElementChild;
            this.overBoxTimer = window.setTimeout(() => {
                if (tbodyDom.scrollHeight > tbodyDom.clientHeight) {
                    child.style.paddingRight = "18px";
                }
                else {
                    child.style.paddingRight = "";
                }
            }, 300);
        }
    }
    componentWillUnmount() {
        const { config } = this.props;
        if (config.forzen) {
            this.tabBodyRef.current.removeEventListener("wheel", this.wheelFn);
        }
        clearTimeout(this.overBoxTimer);
    }
    overBox() {
        const tbodyDom = this.tabBodyRef.current;
        if (tbodyDom.scrollWidth > tbodyDom.clientWidth || tbodyDom.scrollHeight > tbodyDom.clientHeight) {
            const child = this.colHeadRef.current
                .firstElementChild;
            child.style.paddingRight = "18px";
        }
    }
    getBody() {
        const { data, fixObj, fixObj: { idField, childField }, config, viewIndex, changeState, } = this.props;
        const { child: cols } = config;
        let order = { order: 0 };
        const trs = data.map((val, index) => {
            const arr = val.get(childField);
            const id = val.get(idField);
            const isMainView = viewIndex === 0;
            if (arr && arr.size) {
                return (React.createElement(ParTree, { key: id, order: order, changeState: changeState, lev: 0, index: `${index}`, node: val, cols: cols, isMainView: isMainView, fixObj: fixObj }));
            }
            else {
                return (React.createElement(TrItem, { key: id, order: order, node: val, index: `${index}`, changeState: changeState, cols: cols, isMainView: isMainView, lev: 0, fixObj: fixObj }));
            }
        });
        const colgroup = this.createColgroup();
        const fn = !config.forzen ? this.scrollFn : undefined;
        const makeSignFn = !config.forzen ? this.makeSign : undefined;
        return (React.createElement("div", { className: "tab-body-main", onScroll: fn, onMouseEnter: makeSignFn, onMouseLeave: makeSignFn, ref: this.tabBodyRef },
            React.createElement("table", null,
                colgroup,
                React.createElement("tbody", null, trs))));
    }
    render() {
        const { config: { width, forzen }, config, } = this.props;
        const styleObj = width ? forzen ? { width } : { width, flex: "none" } : undefined;
        const className = config.forzen ? "tab-view-fix" : "tab-view-scroll";
        return (React.createElement("div", { className: `${className} tab-viewBody`, style: styleObj },
            React.createElement("div", { className: "tab-head-wrap", ref: this.colHeadRef }, this.gethead()),
            React.createElement("div", { className: "tab-body-wrap" }, this.getBody())));
    }
}
export default TabView;
